<?php

# GET DIRECTORY SIZE (in Mo) =================================================================================
function get_dir_size($dirpath, $exclude_extension = '')
{
    $totalSize = 0;
    $iterator = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dirpath));
    foreach ($iterator as $file)
    {
        $extension = pathinfo($file, PATHINFO_EXTENSION);
        if ($file->isFile() && $extension !== $exclude_extension) $totalSize += $file->getSize();
    }

    return round($totalSize / 1024 / 1024, 2);
}


# DISPLAY FILE SIZE (in Ko) =================================================================================
function display_fileSize($path, $object)
{
    if (is_file($path . '/' . $object))
    {
        return " &nbsp;&nbsp;|--- $object  &nbsp;&nbsp;" . ceil(filesize($path . '/' . $object) / 1024) . "  Ko<br>";
    }
}


# DISPLAY FILE SIZE (in Mo) =================================================================================
function display_dirSize($path, $object)
{
    if (is_dir($path . $object))
    {
        return " &nbsp;&nbsp;|--- $object  &nbsp;&nbsp;" . get_dir_size($path . $object) . "  Mo<br>";
    }
}


# ADD FILE OR DIRECTORY TO PROVIDED ARCHIVE FILE =================================================================================
function addToArchive($archive, $path, $relativePath, $object)
{
    if (is_file($path . '/' . $object))
    {
        $archive->addFile($path . '/' . $object, $relativePath . '/' . $object);
    }
    elseif (is_dir($path . '/' . $object))
    {
        $files = glob($path . '/' . $object . '/*');
        foreach ($files as $f) $archive->addFile($f, $relativePath . '/' . basename($f));
    }
}


# CREATE BUTTON TO DO SOMETHING WITH DATA =================================================================================
function create_button($value, $data, $func)
{
    echo "<form method='post' style='display:inline-block;margin:0.2rem'>";
    echo "<input style='padding: 0.2rem 0.5rem;' id='$data' type='submit' name='submit[$data]' value='$value'/>";
    echo '</form>';

    if (isset($_POST['submit']))
    {
        $func(array_keys($_POST['submit']) [0]);
    }
}


# DOWNLOAD A FILE =================================================================================================
$download_file = function ($file)
{
    header('Content-Description: File Transfer');
    header('Content-Type: application/octet-stream');
    header('Content-Disposition: attachment; filename=' . basename($file));
    header('Content-Transfer-Encoding: binary');
    header('Expires: 0');
    header('Cache-Control: must-revalidate');
    header('Pragma: public');
    header('Content-Length: ' . filesize($file));
    ob_clean();
    flush();
    readfile($file);
};


# REMOVE USER DRAWINGS AND IMAGES LINKED TO A JSON FILE =================================================================================
function remove_user_asset($dir, $protected_array = array())
{
    global $drawings_dir;
    global $images_dir;

    if ('/' . basename($dir) === $drawings_dir || '/' . basename($dir) === $images_dir)
    {
        foreach (scandir($dir) as $file)
        {
            if (!in_array($file, $protected_array)) unlink($dir . '/' . $file);
        }
    }
    rmdir($dir); //delete only if empty
    
}


# BACKUP FOLDER ==============================================================================================================
function backup_data($jsonfile)
{

    global $partial_backup_path;
    global $model_data_file;
    global $drawings_dir;
    global $images_dir;

    $dirPath = dirname($jsonfile);
    $dirName = basename($dirPath);
    // backup in backups/partial/data
    $zipFile = $partial_backup_path . $dirName . '_' . time() . '.zip';
    $archive = new ZipArchive();
    $archive->open($zipFile, ZipArchive::CREATE);
    addToArchive($archive, $dirPath, $dirName, $model_data_file);
    addToArchive($archive, $dirPath, $dirName . $drawings_dir, $drawings_dir);
    addToArchive($archive, $dirPath, $dirName . $images_dir, $images_dir);
    $archive->close();
}


#================================================================================================================================
// BUTTON FUNCTIONS
#================================================================================================================================

# CLEAN A DATA FOLDER (DATA THAT AREN'T IN PRODUCTION)  =========================================================================
$clean_data = function ($jsonfile)
{
    global $model_data_file;
    global $drawings_dir;
    global $images_dir;

    if (is_file($jsonfile) && basename($jsonfile) == $model_data_file)
    {
        backup_data($jsonfile);

        $data = json_decode(file_get_contents($jsonfile));
        $protected_images = array();
        $protected_drawings = array();
        $i = 0;
        foreach ($data as $item)
        {
            if (property_exists($item, 'production'))
            {
                if ($item->{'production'} == 'false') unset($data[$i]);
                else
                {
                    if (property_exists($item, 'img_files')) $protected_images = array_merge($protected_images, $item->{'img_files'});
                    if (property_exists($item, 'draw_file')) $protected_drawings[] = $item->{'draw_file'};
                }
            }
            else unset($data[$i]);
            $i++;
        }

        $data = array_values($data); // rebase array
        if (count($data) > 0) file_put_contents($jsonfile, json_encode($data));
        else unlink($jsonfile);

        remove_user_asset(dirname($jsonfile) . $images_dir, $protected_images);
        remove_user_asset(dirname($jsonfile) . $drawings_dir, $protected_drawings);
    }
    echo "<script> document.getElementById('$jsonfile').value += ' cleaned'; </script>";
};

# REMOVE USER ALL USER DATA EVEN IN PRODUCTION =========================================================================

$remove_user_data = function ($jsonfile)
{
    global $drawings_dir;
    global $images_dir;
    global $model_data_file;

    if (basename($jsonfile) === $model_data_file)
    {
        $dir = dirname($jsonfile);
        backup_data($jsonfile);
        remove_user_asset($dir . $images_dir);
        remove_user_asset($dir . $drawings_dir);
        unlink($jsonfile);
    }
    header('refresh:0');
};


# REMOVE MASK FILE =========================================================================

$remove_mask = function($file)
{
    global $mask_file;
    if (basename($file) === $mask_file) unlink($file);
};

# REMOVE PREVIEW =========================================================================
$remove_preview = function($file)
{
    global $social_preview_file;
    global $preview_file;

    if (basename($file) === $preview_file) 
    {
        unlink($file);
        unlink(dirname($file) . '/' . $social_preview_file);
    }
};